==> logback-classic-1.1.4-test-sources.jar: ch/qos/logback/classic/gaffer/ConfigurationDelegateTest.java <==
package ch.qos.logback.classic.gaffer;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class ConfigurationDelegateTest
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  ch.qos.logback.classic.LoggerContext getContext() { return (ch.qos.logback.classic.LoggerContext)null;}
public  void setContext(ch.qos.logback.classic.LoggerContext value) { }
public  ch.qos.logback.classic.gaffer.ConfigurationDelegate getConfigurationDelegate() { return (ch.qos.logback.classic.gaffer.ConfigurationDelegate)null;}
public  void setConfigurationDelegate(ch.qos.logback.classic.gaffer.ConfigurationDelegate value) { }
public  ch.qos.logback.core.status.StatusChecker getStatusChecker() { return (ch.qos.logback.core.status.StatusChecker)null;}
public  void setStatusChecker(ch.qos.logback.core.status.StatusChecker value) { }
public  int getDiff() { return (int)0;}
public  void setDiff(int value) { }
public  java.lang.String getRandomOutputDir() { return (java.lang.String)null;}
public  void setRandomOutputDir(java.lang.String value) { }
@org.junit.Before() public  void setUp() { }
@org.junit.Test() public  void contextAwareMixin() { }
@org.junit.Test() public  void scan() { }
@org.junit.Test() public  void timestamp() { }
@org.junit.Test() public  void timestampWithContextBirthAsReference() { }
@org.junit.Test() public  void loggerWithoutName() { }
@org.junit.Test() public  void loggerSetLevel() { }
@org.junit.Test() public  void loggerAppenderRef() { }
@org.junit.Test() public  void loggerAdditivity() { }
@org.junit.Test() public  void loggerAdditivittWithEmptyList() { }
@org.junit.Test() public  void root_LEVEL() { }
@org.junit.Test() public  void root_WithList() { }
@org.junit.Test() public  void appender0() { }
@org.junit.Test() public  void appender1() { }
@org.junit.Test() public  void appenderWithEncoder() { }
@org.junit.Test() public  void appenderSMTP() { }
@org.junit.Test() public  void appenderRolling() { }
@org.junit.Test() public  void withSizeAndTimeBasedFNATP() { }
@org.junit.Test() public  void jmxConfiguratorWithDefaults() { }
@org.junit.Test() public  void jmxConfiguratorWithNonDefaultContextName() { }
@org.junit.Test() public  void jmxConfiguratorWithNonDefaultObjectName() { }
}

==> logback-classic-1.2.3-test-sources.jar: ch/qos/logback/classic/gaffer/ConfigurationDelegateTest.java <==
package ch.qos.logback.classic.gaffer;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class ConfigurationDelegateTest
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  ch.qos.logback.classic.LoggerContext getContext() { return (ch.qos.logback.classic.LoggerContext)null;}
public  void setContext(ch.qos.logback.classic.LoggerContext value) { }
public  ch.qos.logback.classic.gaffer.ConfigurationDelegate getConfigurationDelegate() { return (ch.qos.logback.classic.gaffer.ConfigurationDelegate)null;}
public  void setConfigurationDelegate(ch.qos.logback.classic.gaffer.ConfigurationDelegate value) { }
public  ch.qos.logback.core.status.StatusChecker getStatusChecker() { return (ch.qos.logback.core.status.StatusChecker)null;}
public  void setStatusChecker(ch.qos.logback.core.status.StatusChecker value) { }
public  int getDiff() { return (int)0;}
public  void setDiff(int value) { }
public  java.lang.String getRandomOutputDir() { return (java.lang.String)null;}
public  void setRandomOutputDir(java.lang.String value) { }
@org.junit.Before() public  void setUp() { }
@org.junit.Test() public  void contextAwareMixin() { }
@org.junit.Test() public  void scan() { }
@org.junit.Test() public  void timestamp() { }
@org.junit.Test() public  void timestampWithContextBirthAsReference() { }
@org.junit.Test() public  void loggerWithoutName() { }
@org.junit.Test() public  void loggerSetLevel() { }
@org.junit.Test() public  void loggerAppenderRef() { }
@org.junit.Test() public  void loggerAdditivity() { }
@org.junit.Test() public  void loggerAdditivittWithEmptyList() { }
@org.junit.Test() public  void root_LEVEL() { }
@org.junit.Test() public  void root_WithList() { }
@org.junit.Test() public  void appender0() { }
@org.junit.Test() public  void appender1() { }
@org.junit.Test() public  void appenderWithEncoder() { }
@org.junit.Test() public  void appenderSMTP() { }
@org.junit.Test() public  void appenderRolling() { }
@org.junit.Test() public  void withSizeAndTimeBasedFNATP() { }
@org.junit.Test() public  void withSizeAndTimeBasedFNATP_AsString() { }
public  void withSizeAndTimeBasedFNATP(boolean asString) { }
@org.junit.Test() public  void jmxConfiguratorWithDefaults() { }
@org.junit.Test() public  void jmxConfiguratorWithNonDefaultContextName() { }
@org.junit.Test() public  void jmxConfiguratorWithNonDefaultObjectName() { }
}
